@@ -1,4 +1,3 @@
-import requests
 import yaml
 from termcolor import colored
 
@@ -28,5 +27,8 @@ class Profiles:
     def get_email_env(self):
         return self.env['application']['email']
 
+    def get_redis_env(self):
+        return self.env['redis']['config']
+
     def get_operating_system(self):
         return self.file_config.get('operating-system')
